'use strict';

const _ = require('ember-cli-lodash-subset');

const defaults = {
  storeConfigInMeta: 'test' === process.env.EMBER_ENV,

  babel: {
    sourceMaps: 'production' !== process.env.EMBER_ENV && 'inline',
  },

  choiceform: {
    useDeviceJS: true,
    useNormalizeCSS: 'test' !== process.env.EMBER_ENV,
    disableInspector: 'production' === process.env.EMBER_ENV,
  },

  cssModules: {
    postcssOptions: {
      map: 'production' !== process.env.EMBER_ENV,
    },
    plugins: [
      require('postcss-short'),
      require('postcss-clearfix'),
      require('postcss-color-function'),
      require('postcss-preset-env')({
        stage: 0,
        preserve: true,
        importFrom: [
          {
            customMedia: {
              '--mobile': '(width <= 425px)',
              '--over-mobile': '(width >= 426px)',
              '--into-tablet': '(width <= 768px)',
              '--tablet': '(width >= 426px) and (width <= 768px)',
              '--over-tablet': '(width >= 769px)',
              '--into-laptop': '(width <= 1024px)',
              '--laptop': '(width >= 769px) and (width <= 1024px)',
              '--over-laptop': '(width >= 1025px)',
              '--into-desktop': '(width <= 1440px)',
              '--desktop': '(width >= 1025px) and (width <= 1440px)',
              '--over-desktop': '(width >= 1441px)',
            },
            customProperties: {
              // Primary color
              '--primary': '#2196F3',
              '--primary-darker': '#0079C4',

              // Secondary color
              '--secondary': '#4ECE3D',
              '--secondary-darker': '#40B630',

              // Accent color
              '--accent': '#373277',

              // Bright theme palette
              '--palette-bright-01': '#A8C6DF',
              '--palette-bright-02': '#C5D9E8',
              '--palette-bright-03': '#ECF5FD',
              '--palette-bright-04': '#FAFBFC',

              // Dark theme palette
              '--palette-dark-01': '#212F40',
              '--palette-dark-02': '#2C405A',
              '--palette-dark-03': '#3F536E',
              '--palette-dark-04': '#8DABC4',

              // Dark text on light backgrounds
              // Primary text
              '--primary-text-dark': '#3F536E',
              // Secondary text
              '--secondary-text-dark': '#8DABC4',
              // Disabled text, hint text, and icons
              '--disabled-text-dark': '#A8C6DF',
              // Dividers
              '--dividers-dark': '#C5D9E8',

              // White text on dark backgrounds
              // Primary text
              '--primary-text-white': '#ECF5FD',
              // Secondary text
              '--secondary-text-white': '#8DABC4',
              // Disabled text, hint text, and icons
              '--disabled-text-white': '#5b718c',
              // Dividers
              '--dividers-white': '#3F536E',

              // Gray Colors
              '--midnight': '#212F40',
              '--catalina-blue': '#2C405A',
              '--fiord': '#3F536E',
              '--nepal': '#8DABC4',
              '--light-steel-blue': '#A8C6DF',
              '--botticelli': '#C5D9E8',
              '--zumthor': '#ECF5FD',
              '--alabaster': '#FAFBFC',
              '--white': '#FFF',
              '--black': '#000',

              // Active Colors
              '--cool-blue': '#0093EE',
              '--dull-lime': '#4ECE3D',
              '--ruddy': '#FF151F',
              '--cool-blue-active': '#0079C4',
              '--dull-lime-active': '#40B630',

              // Branding Colors
              '--soft-purple': '#AB7DF6',
              '--java': '#26C2C9',
              '--supernova': '#FACA00',
              '--lime': '#81C926',
              '--pumpkin': '#FD7B1F',

              // Typography
              '--font-size': '1rem',
              '--font-bold': '600',

              // Border Radius
              '--radius-small': '2px',
              '--radius-medium': '3px',
              '--radius-large': '4px',
              '--radius-big': 'calc(var(--offset) / 2)',

              // Offset
              '--offset': '2rem',
              '--offset-half': '1rem',

              // Z-index
              '--ui-dropdown': '10',
              '--ui-popup': 'calc(var(--ui-dropdown) + 1)',
              '--ui-modal': 'calc(var(--ui-popup) + 1)',
              '--ui-loading': 'calc(var(--ui-modal) + 1)',
              '--ui-notification': 'calc(var(--ui-loading) + 1)',
            },
          },
        ],
        exportTo: 'config/postcss.js',
      }),
      require('postcss-object-fit-images'),
      require('postcss-merge-rules'),
      require('postcss-discard-comments'),
      require('postcss-discard-duplicates'),
    ],
  },

  svgJar: {
    rootURL: '/',
    strategy: 'symbol',
    sourceDirs: ['public/assets/svg'],
  },
};

module.exports = function(options) {
  return _.merge(defaults, options);
};
