'use strict';

const mergeTrees = require('broccoli-merge-trees');
const resolve = require('resolve');
const path = require('path');
const Funnel = require('broccoli-funnel');
const stew = require('broccoli-stew');
const _ = require('ember-cli-lodash-subset');

module.exports = {
  name: require('./package').name,

  config() {
    return {
      [this.name]: {
        version: require('./package').version,
      },
    };
  },

  treeForVendor() {
    const defaultTree = this._super.treeForAddon.apply(this, arguments);

    if (this.options.choiceform.useDeviceJS) {
      const deviceJSTree = this.transformDeviceJSToCompatibleWithFastBoot();
      return defaultTree
        ? new mergeTrees([defaultTree, deviceJSTree])
        : deviceJSTree;
    }

    return defaultTree;
  },

  transformDeviceJSToCompatibleWithFastBoot() {
    const options = {
      srcDir: 'dist',
      include: ['device.umd.js'],
      destDir: 'device.js',
    };
    const baseDir = __dirname;
    const devicePath = resolve.sync('device.js/package.json', { baseDir });
    const wrapperFunc = content =>
      `if (typeof FastBoot === 'undefined') {\n${content}\n` +
      `window.device = device.device; device.addClasses(document.documentElement);\n}`;
    return stew.map(new Funnel(path.dirname(devicePath), options), wrapperFunc);
  },

  included(host) {
    this.options = _.merge(this.options, host.options);
    this._super.included.apply(this, arguments);

    this.importObjectFitPolyfill();

    const choiceform = this.options.choiceform;
    choiceform.useDeviceJS && this.importDeviceJS();
    choiceform.useNormalizeCSS && this.importNormalizeCSS();
  },

  importObjectFitPolyfill() {
    this.import('node_modules/object-fit-images/dist/ofi.js');
  },

  importDeviceJS() {
    this.import('vendor/device.js/device.umd.js');
  },

  importNormalizeCSS() {
    this.import('node_modules/normalize.css/normalize.css', {
      outputFile: 'assets/normalize.css',
    });
  },

  contentFor(type, config) {
    const root = config.rootURL;

    if ('head' === type) {
      const content = [];

      if (this.options.choiceform.useNormalizeCSS) {
        content.push(
          `<link integrity="" rel="stylesheet" href="${root}assets/normalize.css">`
        );
      }

      if (this.options.choiceform.disableInspector) {
        content.push(`<script>window.NO_EMBER_DEBUG = true;</script>`);
      }

      return content.join('\n');
    }
  },
};
